@@ -5,8 +5,8 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2023
-;; Package-Version: 20260104.1105
-;; Package-Revision: 331ed3d8f45d
+;; Package-Version: 20260117.1650
+;; Package-Revision: b412673dec75
 ;; Package-Requires: ((emacs "29.1") (compat "30"))
 ;; URL: https://github.com/minad/jinx
 ;; Keywords: convenience, text
@@ -1086,9 +1086,10 @@ This command dispatches to the following commands:
     (insert word)
     (exit-minibuffer)))
 
-(defun jinx-next (n)
+(defun jinx-next (&optional n)
   "Go to to Nth next misspelled word."
   (interactive "p" jinx-mode)
+  (unless n (setq n 1))
   (unless (= n 0)
     (if (minibufferp)
         (throw 'jinx--goto n)
@@ -1098,10 +1099,10 @@ This command dispatches to the following commands:
         (goto-char (overlay-end (nth (mod n (length ov)) ov)))
         (jinx--invisible-open-permanently)))))
 
-(defun jinx-previous (n)
+(defun jinx-previous (&optional n)
   "Go to to Nth previous misspelled word."
   (interactive "p" jinx-mode)
-  (jinx-next (- n)))
+  (jinx-next (- (or n 1))))
 
 ;;;###autoload
 (define-minor-mode jinx-mode
